package com.dgtly.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.MetaHanaDeliverSignMapper;
import com.dgtly.system.domain.MetaHanaDeliverSign;
import com.dgtly.system.service.IMetaHanaDeliverSignService;
import com.dgtly.common.core.text.Convert;

/**
 * 电子单签收状态数量Service业务层处理
 *
 * @author dgtly
 * @date 2025-01-03
 */
@Service
public class MetaHanaDeliverSignServiceImpl implements IMetaHanaDeliverSignService
{
    @Autowired
    private MetaHanaDeliverSignMapper metaHanaDeliverSignMapper;

    /**
     * 查询电子单签收状态数量
     *
     * @param deliverNumber 电子单签收状态数量ID
     * @return 电子单签收状态数量
     */
    @Override
    public MetaHanaDeliverSign selectMetaHanaDeliverSignById(String deliverNumber)
    {
        return metaHanaDeliverSignMapper.selectMetaHanaDeliverSignById(deliverNumber);
    }

    /**
     * 查询电子单签收状态数量列表
     *
     * @param metaHanaDeliverSign 电子单签收状态数量
     * @return 电子单签收状态数量
     */
    @Override
    public List<MetaHanaDeliverSign> selectMetaHanaDeliverSignList(MetaHanaDeliverSign metaHanaDeliverSign)
    {
        return metaHanaDeliverSignMapper.selectMetaHanaDeliverSignList(metaHanaDeliverSign);
    }



    /**
     * 修改电子单签收状态数量
     *
     * @param metaHanaDeliverSign 电子单签收状态数量
     * @return 结果
     */
    @Override
    public int updateMetaHanaDeliverSign(MetaHanaDeliverSign metaHanaDeliverSign)
    {
        return metaHanaDeliverSignMapper.updateMetaHanaDeliverSign(metaHanaDeliverSign);
    }

    /**
     * 删除电子单签收状态数量对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteMetaHanaDeliverSignByIds(String ids)
    {
        return metaHanaDeliverSignMapper.deleteMetaHanaDeliverSignByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除电子单签收状态数量信息
     *
     * @param deliverNumber 电子单签收状态数量ID
     * @return 结果
     */
    @Override
    public int deleteMetaHanaDeliverSignById(String deliverNumber)
    {
        return metaHanaDeliverSignMapper.deleteMetaHanaDeliverSignById(deliverNumber);
    }


}
